#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-D8MonZtqCckE4J4swx9DtS
key:                  haskell-language-server-2.3.0.0-D8MonZtqCckE4J4swx9DtS
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  041a3a1de45482c741570b3cfae8eb15
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-D8MonZtqCckE4J4swx9DtS
depends:
    aeson-pretty-0.8.11-nawxSYmL7TDqr8VRhwNQe
    async-2.2.6-13RsU0DgnQr2Fu0srq1209 base-4.18.2.1
    base16-bytestring-1.0.2.0-Dowr9jBdlVZBVCdnm9XhEq
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-HXk16cNaAybHdJ4S2vrEoS
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-5TJRL61mQdJ37nJ79jr8U filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-7duM3clEm838olJp6ftF2j
    githash-0.1.7.0-961G3VId53S1j2pOyAlOQT
    hie-bios-0.12.0-IaUq6Ldfd7JCTtEdjw30Zh
    hiedb-0.4.3.0-I2TIZPLmsU77RUeBojIIkv
    hls-alternate-number-format-plugin-2.3.0.0-3hFdFJrSlV72bbQUKKVld3
    hls-cabal-fmt-plugin-2.3.0.0-4BZBi3QiqUC71vFciBHzGp
    hls-cabal-plugin-2.3.0.0-4b0diUQEM2IJUzCRLtzgKM
    hls-call-hierarchy-plugin-2.3.0.0-9PNOEKdUrqhEj0SqiNlP1F
    hls-change-type-signature-plugin-2.3.0.0-IjRm5uyA8Z65DvPpSisoaG
    hls-class-plugin-2.3.0.0-I059L6zF5mD9QoOxAbTsGf
    hls-code-range-plugin-2.3.0.0-AIcHdvNtoX2rAa8oekI81
    hls-eval-plugin-2.3.0.0-ABFpD0K4E0K3IoyuXDz9nQ
    hls-explicit-fixity-plugin-2.3.0.0-66SLLFH9Pc2pql1vrDSBV
    hls-explicit-imports-plugin-2.3.0.0-6NNkeKygLFLDRZhAA03fTT
    hls-explicit-record-fields-plugin-2.3.0.0-LaRLOsPfWazEVaT67Of4u0
    hls-fourmolu-plugin-2.3.0.0-AOjraLKvzsKEDatup8DfiQ
    hls-gadt-plugin-2.3.0.0-HXskyqERdy3LLGJcSvri4S
    hls-graph-2.3.0.0-3obfORsOpfjI761oVK9imG
    hls-hlint-plugin-2.3.0.0-ABhqTRR414KHBOl1K850C5
    hls-module-name-plugin-2.3.0.0-a73zXSipiDHvJ7BS0doYJ
    hls-ormolu-plugin-2.3.0.0-2LSFTfmTvtQFsqBFiGTfU4
    hls-overloaded-record-dot-plugin-2.3.0.0-E5i8zH1NKO3LTwt4ZshCYl
    hls-plugin-api-2.3.0.0-JAC6EX6AfCOGEdv3lJ0Ao6
    hls-pragmas-plugin-2.3.0.0-783t71Z3mPNLNHkAVVe8pL
    hls-qualify-imported-names-plugin-2.3.0.0-5sYx9iA7N7fGPArqa8T8TJ
    hls-refactor-plugin-2.3.0.0-3Yh2DqO1BcuX7PqSR6Vtq
    hls-rename-plugin-2.3.0.0-4yIAQrfcyJp31JSV7Po0RX
    hls-retrie-plugin-2.3.0.0-KJWxFUdjfJw2R7AqPaYGJG
    hls-splice-plugin-2.3.0.0-B1VbK1p5sa772bkXThaWu1
    hls-stylish-haskell-plugin-2.3.0.0-J0xLLUJnj4THdJkhFk7lEv
    lsp-2.2.0.0-ASJx8lMy3AeIMffE9ZbIv9
    optparse-applicative-0.18.1.0-7VN2J9FD8HH2Bl1L5dRVhn
    optparse-simple-0.1.1.4-45hSthJ6DGz1XrlHcWyrx
    prettyprinter-1.7.1-E27IB52rJzT5cRmoGOw0uk process-1.6.19.0
    safe-exceptions-0.1.7.4-3wk6Rchm5LTH7MUPQ2VD18
    sqlite-simple-0.4.19.0-CBYT7e2xIwTIBJpsvxSn0Q text-2.0.2
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

